@@ -36,13 +36,20 @@ def _plot_colors(
     colorspace: str = "cam16",
     saturation_adjustment: float = 1.28,
 ):
+    rgb_vals = get_srgb1(
+        fz,
+        abs_scaling=abs_scaling,
+        colorspace=colorspace,
+        saturation_adjustment=saturation_adjustment,
+    )
+
+    # set nan values to white
+    assert rgb_vals.shape[-1] == 3
+    is_nan = np.any(np.isnan(rgb_vals), axis=-1)
+    rgb_vals[is_nan] = [1.0, 1.0, 1.0]
+
     plt.imshow(
-        get_srgb1(
-            fz,
-            abs_scaling=abs_scaling,
-            colorspace=colorspace,
-            saturation_adjustment=saturation_adjustment,
-        ),
+        rgb_vals,
         extent=extent,
         # Don't use "nearest" interpolation, it creates color blocking artifacts:
         # <https://github.com/matplotlib/matplotlib/issues/21499>
@@ -89,7 +96,7 @@ def _add_colorbar_abs(cax, abs_scaling: Callable, abs_contours: float | list[flo
     if isinstance(abs_contours, (int, float)):
         a = abs_contours
         scaled_vals = abs_scaling(
-            np.array([1 / a ** 3, 1 / a ** 2, 1 / a, 1, a, a ** 2, a ** 3])
+            np.array([1 / a**3, 1 / a**2, 1 / a, 1, a, a**2, a**3])
         )
         cb0.set_ticks([0.0, *scaled_vals, 1.0])
         if isinstance(abs_contours, int) and abs_contours < 4:
@@ -169,8 +176,8 @@ def _plot_contour_abs(
             max_exp = np.log(maxval) / np.log(base)
             max_exp = int(min(max_exp, 100))
 
-        contours_neg = [base ** k for k in range(min_exp, 0)]
-        contours_pos = [base ** k for k in range(1, max_exp + 1)]
+        contours_neg = [base**k for k in range(min_exp, 0)]
+        contours_pos = [base**k for k in range(1, max_exp + 1)]
 
         _plot_contour(contours_neg, color if color else "0.8", "solid", alpha)
         if emphasize_contour_1:
@@ -264,7 +271,11 @@ def plot(
 ):
     extent = (x_range[0], x_range[1], y_range[0], y_range[1])
     Z = _get_z_grid_for_image(x_range, y_range)
-    fz = f(Z)
+
+    # always reshape to vector, makes it easier for f()
+    Z_shape = Z.shape
+    fz = f(Z.flatten()).reshape(Z_shape)
+
     _plot(Z, fz, extent, *args, **kwargs)
     return plt
 
@@ -297,7 +308,7 @@ def _plot(
         alpha = np.log(2) / np.log(abs_scaling)
 
         def alpha_scaling(r):
-            return r ** alpha / (r ** alpha + 1)
+            return r**alpha / (r**alpha + 1)
 
         asc = alpha_scaling
 
@@ -418,7 +429,10 @@ def plot_contours(
     saturation_adjustment: float = 1.28,
 ):
     Z = _get_z_grid_for_image(x_range, y_range)
-    fz = f(Z)
+
+    # always reshape to vector, makes it easier for f()
+    Z_shape = Z.shape
+    fz = f(Z.flatten()).reshape(Z_shape)
 
     if contours_arg is not None:
         _plot_contour_arg(
